@@ -53,6 +53,7 @@
 #include <gtk/gtkmisc.h>
 #include <gtk/gtknotebook.h>
 #include <gtk/gtktable.h>
+#include <gtk/gtkspinbutton.h>
 #include <gtk/gtktogglebutton.h>
 #endif
 
@@ -61,6 +62,24 @@
 /* this should be per model */
 #define PAD_HACK	4	/* pts */
 
+static struct {
+	GogAxisPolarUnit unit;
+	const char 	*name;
+	double		 perimeter;
+	const char	*xl_format;
+	double		 auto_minimum;
+	double		 auto_maximum;
+	double		 auto_major;
+	double		 auto_minor;	
+} polar_units[GOG_AXIS_POLAR_UNIT_MAX] = {
+	{ GOG_AXIS_POLAR_UNIT_DEGREES, N_("Degrees"), 360.0,	"0\"°\"",   0.0, 360.0,     30.0,      10.0},
+	{ GOG_AXIS_POLAR_UNIT_RADIANS, N_("Radians"), 2 * M_PI,	"?pi/??", -M_PI,  M_PI, M_PI/4.0, M_PI/16.0},
+	{ GOG_AXIS_POLAR_UNIT_GRADS,   N_("Grads"),   400.0,	"General",  0.0, 400.0,     50.0,      10.0}
+};
+
+#define GOG_AXIS_CIRCULAR_ROTATION_MIN -180.0
+#define GOG_AXIS_CIRCULAR_ROTATION_MAX  180.0
+
 typedef struct _GogAxisMapDesc GogAxisMapDesc;
 
 struct _GogAxis {
@@ -84,6 +103,9 @@ struct _GogAxis {
 
 	GogAxisMapDesc const 	*map_desc;
 
+	GogAxisPolarUnit	 polar_unit;
+	double			 circular_rotation;
+
 	GogAxisTick	*ticks;
 	unsigned	 tick_nbr;
 };
@@ -99,26 +121,6 @@ struct _GogAxis {
 
 static void gog_axis_set_ticks (GogAxis *axis,int tick_nbr, GogAxisTick *ticks);
 
-static GogAxisTick *
-get_adjusted_tick_array (GogAxisTick *ticks, int allocated_size, int exact_size) 
-{
-	GogAxisTick *tmp_ticks;
-	
-	if (exact_size > 0) {
-		if (exact_size != allocated_size) {
-			tmp_ticks = g_new (GogAxisTick, exact_size);
-			memcpy (tmp_ticks, ticks, sizeof (GogAxisTick) * exact_size);
-			g_free (ticks);
-		} else
-			tmp_ticks = ticks;
-	} else {
-		g_free (ticks);
-		tmp_ticks = NULL;
-	}
-
-	return tmp_ticks;
-}
-
 static GogAxisTick *
 create_invalid_axis_ticks (double min, double max) 
 {
@@ -232,7 +234,7 @@ map_discrete_auto_bound (GogAxis *axis,
 	if ((maximum - minimum) > GOG_AXIS_DISCRETE_AUTO_MAX_MAJOR_TICK_NBR) 
 		bound [GOG_AXIS_ELEM_MAJOR_TICK] = 
 		bound [GOG_AXIS_ELEM_MINOR_TICK] =
-			ceil ((maximum - minimum + 1.0) / 
+			go_fake_ceil ((maximum - minimum + 1.0) / 
 			      (double) GOG_AXIS_DISCRETE_AUTO_MAX_MAJOR_TICK_NBR); 
 	else
 		bound [GOG_AXIS_ELEM_MAJOR_TICK] = 
@@ -267,11 +269,11 @@ map_discrete_calc_ticks (GogAxis *axis)
 	}
 		
 	tick_start = axis->center_on_ticks ? 
-		ceil (minimum / (double) major_tick) * major_tick : 
-		ceil ((minimum - 0.5) / (double) major_tick) * major_tick + 0.5;
-	label_start = ceil (minimum / (double) major_label) * major_label;
-	tick_nbr = floor (go_add_epsilon (maximum - tick_start) / major_tick + 1.0);
-	label_nbr = floor (go_add_epsilon (maximum - label_start) / major_label + 1.0);
+		go_fake_ceil (minimum / (double) major_tick) * major_tick : 
+		go_fake_ceil ((minimum - 0.5) / (double) major_tick) * major_tick + 0.5;
+	label_start = go_fake_ceil (minimum / (double) major_label) * major_label;
+	tick_nbr = go_fake_floor ((maximum - tick_start) / major_tick + 1.0);
+	label_nbr = go_fake_floor ((maximum - label_start) / major_label + 1.0);
 	tick_nbr = CLAMP (tick_nbr, 0, GOG_AXIS_MAX_TICK_NBR);
 	label_nbr = CLAMP (label_nbr, 0, GOG_AXIS_MAX_TICK_NBR);
 	if (tick_nbr < 1  && label_nbr < 1) {
@@ -385,10 +387,10 @@ map_linear_auto_bound (GogAxis *axis, double minimum, double maximum, double *bo
 	int expon;
 
 	if (gog_axis_get_atype (axis) == GOG_AXIS_CIRCULAR) {
-		bound[GOG_AXIS_ELEM_MIN] = 0.0;
-		bound[GOG_AXIS_ELEM_MAX] = 360.0;
-		bound[GOG_AXIS_ELEM_MAJOR_TICK] = 30.0;
-		bound[GOG_AXIS_ELEM_MINOR_TICK] = 10.0;
+		bound[GOG_AXIS_ELEM_MIN] = polar_units[axis->polar_unit].auto_minimum;
+		bound[GOG_AXIS_ELEM_MAX] = polar_units[axis->polar_unit].auto_maximum;
+		bound[GOG_AXIS_ELEM_MAJOR_TICK] = polar_units[axis->polar_unit].auto_major;
+		bound[GOG_AXIS_ELEM_MINOR_TICK] = polar_units[axis->polar_unit].auto_minor;
 		return;
 	}	
 
@@ -459,13 +461,13 @@ map_linear_calc_ticks (GogAxis *axis)
 	if (major_tick <= 0.) major_tick = maximum - minimum;
 	if (minor_tick <= 0.) minor_tick = maximum - minimum;
 	if (minor_tick < major_tick) {
-		minor_tick = major_tick / rint (major_tick / minor_tick);
+		minor_tick = major_tick / go_rint (major_tick / minor_tick);
 		tick_step = minor_tick;
 	} else
 		tick_step = major_tick;
 	
-	start = ceil (minimum / tick_step) * tick_step;
-	tick_nbr = floor (go_add_epsilon ((maximum - start) / tick_step + 1.0));
+	start = go_fake_ceil (minimum / tick_step) * tick_step;
+	tick_nbr = go_fake_floor ((maximum - start) / tick_step + 1.0);
 	if (tick_nbr < 1 || tick_nbr > GOG_AXIS_MAX_TICK_NBR) {
 		gog_axis_set_ticks (axis, 0, NULL);
 		return;
@@ -474,19 +476,19 @@ map_linear_calc_ticks (GogAxis *axis)
 
 	for (i = 0; i < tick_nbr; i++) {
 		ticks[i].position = start + (double) i * tick_step;
-		if (fabs (ticks[i].position) < tick_step / 1E10)
+		if (fabs (ticks[i].position) < tick_step * 1e-10)
 			ticks[i].position = 0.0;
 		ratio = ticks[i].position / major_tick;
-		if (fabs (ratio - rint (ratio)) < 1E-3) {
+		if (fabs (ratio - go_rint (ratio)) < 1E-3) {
 			ticks[i].type = GOG_AXIS_TICK_MAJOR;
-				if (axis->assigned_format == NULL || 
-				    go_format_is_general (axis->assigned_format))
-					ticks[i].label = go_format_value (axis->format, 
-									  ticks[i].position);
-				else
-					ticks[i].label = go_format_value (axis->assigned_format, 
-									  ticks[i].position);
-			}
+			if (axis->assigned_format == NULL || 
+			    go_format_is_general (axis->assigned_format))
+				ticks[i].label = go_format_value (axis->format, 
+								  ticks[i].position);
+			else
+				ticks[i].label = go_format_value (axis->assigned_format, 
+								  ticks[i].position);
+		}
 		else {
 			ticks[i].type = GOG_AXIS_TICK_MINOR;
 			ticks[i].label = NULL;
@@ -613,10 +615,10 @@ map_log_auto_bound (GogAxis *axis, double minimum, double maximum, double *bound
 	if (maximum < minimum)
 		maximum = minimum * 100.0;
 
-	maximum = ceil (log10 (maximum));
-	minimum = floor (log10 (minimum));
+	maximum = go_fake_ceil (log10 (maximum));
+	minimum = go_fake_floor (log10 (minimum));
 	
-	step = ceil ((maximum - minimum + 1.0) / 
+	step = go_fake_ceil ((maximum - minimum + 1.0) / 
 		     (double) GOG_AXIS_LOG_AUTO_MAX_MAJOR_TICK_NBR); 
 
 	bound [GOG_AXIS_ELEM_MIN] = pow ( 10.0, minimum);
@@ -635,8 +637,8 @@ map_log_calc_ticks (GogAxis *axis)
 	int tick_nbr, i, j;
 	int count;
 
-	major_label = rint (gog_axis_get_entry (axis, GOG_AXIS_ELEM_MAJOR_TICK, NULL));
-	minor_tick = rint (gog_axis_get_entry (axis, GOG_AXIS_ELEM_MINOR_TICK, NULL) + 1.0);
+	major_label = go_rint (gog_axis_get_entry (axis, GOG_AXIS_ELEM_MAJOR_TICK, NULL));
+	minor_tick = go_rint (gog_axis_get_entry (axis, GOG_AXIS_ELEM_MINOR_TICK, NULL) + 1.0);
 
 	if (!gog_axis_get_bounds (axis, &minimum, &maximum) || major_label < 1) {
 		gog_axis_set_ticks (axis, 2, create_invalid_axis_ticks (1.0, 10.0));
@@ -647,8 +649,9 @@ map_log_calc_ticks (GogAxis *axis)
 		return;
 	}
 
-	start_tick = ceil (log10 (minimum));
-	tick_nbr = major_tick = ceil (ceil (log10 (maximum)) - floor (log10 (minimum)) + 1.0);
+	start_tick = go_fake_floor (log10 (minimum));
+	tick_nbr = major_tick = go_fake_ceil (go_fake_ceil (log10 (maximum)) - 
+					      go_fake_floor (log10 (minimum)) + 1.0);
 	tick_nbr *= minor_tick;
 	if (tick_nbr < 1 || tick_nbr > GOG_AXIS_MAX_TICK_NBR) {
 		gog_axis_set_ticks (axis, 0, NULL);
@@ -678,18 +681,21 @@ map_log_calc_ticks (GogAxis *axis)
 				count++;
 			}
 		} 
-			for (j = 1; j < minor_tick; j++) {
-				position = pow (10.0, i + start_tick) * (9.0 / (double)minor_tick * (double) j + 1.0);
-				if (position >= go_sub_epsilon (minimum) && go_sub_epsilon (position) <= maximum) {
-					ticks[count].position = position;
-					ticks[count].type = GOG_AXIS_TICK_MINOR;
-					ticks[count].label = NULL;
-					count++;
-				}
+		for (j = 1; j < minor_tick; j++) {
+			position = pow (10.0, i + start_tick) * (9.0 / (double)minor_tick * (double) j + 1.0);
+			if (position >= go_sub_epsilon (minimum) && go_sub_epsilon (position) <= maximum) {
+				ticks[count].position = position;
+				ticks[count].type = GOG_AXIS_TICK_MINOR;
+				ticks[count].label = NULL;
+				count++;
 			}
+		}
 	}
 
-	ticks = get_adjusted_tick_array (ticks, tick_nbr, count);
+	if (count > tick_nbr)
+		g_critical ("[GogAxisMap::log_calc_ticks] wrong memory allocation size");
+
+	ticks = g_renew (GogAxisTick, ticks, count);
 	gog_axis_set_ticks (axis, count, ticks);
 }
 
@@ -1044,7 +1050,9 @@ enum {
 	AXIS_PROP_TYPE,
 	AXIS_PROP_INVERT,
 	AXIS_PROP_MAP,
-	AXIS_PROP_ASSIGNED_FORMAT_STR_XL
+	AXIS_PROP_ASSIGNED_FORMAT_STR_XL,
+	AXIS_PROP_CIRCULAR_ROTATION,
+	AXIS_PROP_POLAR_UNIT
 };
 
 /*****************************************************************************/
@@ -1121,9 +1129,11 @@ role_label_can_add (GogObject const *parent)
  * Absorbs a reference to @fmt, and accepts NULL.
  * returns TRUE if things changed
  **/
-static gboolean
+gboolean
 gog_axis_set_format (GogAxis *axis, GOFormat *fmt)
 {
+	g_return_val_if_fail (IS_GOG_AXIS (axis), FALSE);
+
 	if (go_format_eq (fmt, axis->assigned_format)) {
 		go_format_unref (fmt);
 		return FALSE;
@@ -1131,9 +1141,24 @@ gog_axis_set_format (GogAxis *axis, GOFormat *fmt)
 	if (axis->assigned_format != NULL)
 		go_format_unref (axis->assigned_format);
 	axis->assigned_format = fmt;
+
+	gog_object_request_update (GOG_OBJECT (axis));
 	return TRUE;
 }
 
+/**
+ * gog_axis_get_format :
+ * @axis :#GogAxis
+ *
+ * Returns the format assigned to @axis but does not add a reference.
+ **/
+GOFormat *
+gog_axis_get_format (GogAxis const *axis)
+{
+	g_return_val_if_fail (IS_GOG_AXIS (axis), NULL);
+	return axis->assigned_format;
+}
+
 static void
 gog_axis_set_property (GObject *obj, guint param_id,
 		       GValue const *value, GParamSpec *pspec)
@@ -1176,6 +1201,23 @@ gog_axis_set_property (GObject *obj, guint param_id,
 		calc_ticks = resized;
 		break;
 	}
+	case AXIS_PROP_CIRCULAR_ROTATION:
+		axis->circular_rotation = CLAMP (g_value_get_double (value),
+						 GOG_AXIS_CIRCULAR_ROTATION_MIN,
+						 GOG_AXIS_CIRCULAR_ROTATION_MAX);
+		break;
+	case AXIS_PROP_POLAR_UNIT: {
+		char const *str = g_value_get_string (value);
+		unsigned int i;
+		for (i = 0; i < G_N_ELEMENTS (polar_units); i++) {
+			if (g_ascii_strcasecmp (str, polar_units[i].name) == 0) {
+				axis->polar_unit = i;
+				break;
+			}
+		}
+		resized = calc_ticks = TRUE;
+		break;
+	}
 
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		 return; /* NOTE : RETURN */
@@ -1213,6 +1255,12 @@ gog_axis_get_property (GObject *obj, guint param_id,
 		else
 			g_value_set_static_string (value, NULL);
 		break;
+	case AXIS_PROP_CIRCULAR_ROTATION:
+		g_value_set_double (value, axis->circular_rotation);
+		break;
+	case AXIS_PROP_POLAR_UNIT:
+		g_value_set_string (value, polar_units[axis->polar_unit].name);
+		break;
 
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		 break;
@@ -1368,6 +1416,23 @@ gog_axis_update (GogObject *obj)
 }
 
 #ifdef GOFFICE_WITH_GTK
+
+typedef struct {
+	GladeXML 	*gui;
+	GogAxis		*axis;
+	GtkWidget 	*format_selector;	
+} GogAxisPrefState;
+
+static void
+gog_axis_pref_state_free (GogAxisPrefState *state)
+{
+	if (state->axis != NULL)
+		g_object_unref (state->axis);
+	if (state->gui != NULL)
+		g_object_unref (state->gui);
+	g_free (state);
+}
+
 static void
 cb_axis_toggle_changed (GtkToggleButton *toggle_button, GObject *axis)
 {
@@ -1474,7 +1539,7 @@ make_dim_editor (GogDataset *set, GtkTable *table, unsigned dim,
 static void
 cb_axis_fmt_changed (G_GNUC_UNUSED GtkWidget *widget,
 		     char *fmt,
-		     GObject *axis)
+		     GogAxis *axis)
 {
 	g_object_set (axis, "assigned-format-string-XL", fmt, NULL);
 }
@@ -1486,6 +1551,45 @@ cb_map_combo_changed (GtkComboBox *combo,
 	gog_axis_map_set_by_num (axis, gtk_combo_box_get_active (combo));
 }
 
+static void
+gog_axis_populate_polar_unit_combo (GogAxis *axis, GtkComboBox *combo)
+{
+	unsigned i, id = 0;
+
+	g_return_if_fail (IS_GOG_AXIS (axis));
+
+	for (i = 0; i < G_N_ELEMENTS (polar_units); i++) {
+		gtk_combo_box_append_text (combo, _(polar_units[i].name));
+		if (polar_units[i].unit == axis->polar_unit)
+			id = i;
+	}
+	gtk_combo_box_set_active (combo, id);
+}
+
+static void
+cb_polar_unit_changed (GtkComboBox *combo,
+		       GogAxisPrefState *state)
+{
+	GogAxis *axis = state->axis;
+	GOFormat *format;
+
+	axis->polar_unit = gtk_combo_box_get_active (combo);
+	format = go_format_new_from_XL (polar_units[axis->polar_unit].xl_format, FALSE);
+
+	if (gog_axis_set_format (axis, format) &&
+	    state->format_selector != NULL) 
+		go_format_sel_set_style_format (GO_FORMAT_SEL (state->format_selector), format);
+}
+
+static void
+cb_rotation_changed (GtkSpinButton *spin, GogAxis *axis)
+{
+	axis->circular_rotation = CLAMP (gtk_spin_button_get_value (spin), 
+					 GOG_AXIS_CIRCULAR_ROTATION_MIN, 
+					 GOG_AXIS_CIRCULAR_ROTATION_MAX);
+	gog_object_emit_changed (GOG_OBJECT (axis), TRUE);
+}
+
 static void
 gog_axis_populate_editor (GogObject *gobj, 
 			  GogEditor *editor, 
@@ -1500,6 +1604,7 @@ gog_axis_populate_editor (GogObject *gobj,
 	GtkTable  *table;
 	unsigned i = 0;
 	GogAxis *axis = GOG_AXIS (gobj);
+	GogAxisPrefState *state;
 	GogDataset *set = GOG_DATASET (gobj);
 	GladeXML *gui;
 
@@ -1507,6 +1612,11 @@ gog_axis_populate_editor (GogObject *gobj,
 	if (gui == NULL)
 		return;
 
+	state = g_new0 (GogAxisPrefState, 1);
+	state->gui = gui;
+	state->axis = axis;
+	g_object_ref (G_OBJECT (axis));
+
 	/* Bounds Page */
 	table = GTK_TABLE (glade_xml_get_widget (gui, "bound_table"));
 	if (axis->is_discrete) {
@@ -1544,6 +1654,24 @@ gog_axis_populate_editor (GogObject *gobj,
 		gtk_widget_hide (w);
 	}
 
+	if (!axis->is_discrete && gog_axis_get_atype (axis) == GOG_AXIS_CIRCULAR) {
+		GtkWidget *w = glade_xml_get_widget (gui, "polar_unit_combo");
+		gog_axis_populate_polar_unit_combo (axis, GTK_COMBO_BOX (w));
+		g_signal_connect (G_OBJECT (w),
+				  "changed",
+				  G_CALLBACK (cb_polar_unit_changed),
+				  state);
+
+		w = glade_xml_get_widget (gui, "circular_rotation_spinbutton");
+		gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), axis->circular_rotation);
+		g_signal_connect_object (G_OBJECT (w), "value-changed",
+					 G_CALLBACK (cb_rotation_changed),
+					 axis, 0);
+	} else {
+		GtkWidget *w = glade_xml_get_widget (gui, "circular_table");
+		gtk_widget_hide (w);
+	}
+
 	for (i = 0; i < G_N_ELEMENTS (toggle_props) ; i++) {
 		gboolean cur_val;
 		GtkWidget *w = glade_xml_get_widget (gui, toggle_props[i]);
@@ -1564,11 +1692,9 @@ gog_axis_populate_editor (GogObject *gobj,
 
 	/* Format page */
 	if (!axis->is_discrete && gog_axis_get_atype (axis) != GOG_AXIS_PSEUDO_3D) {
-#ifdef GOFFICE_WITH_CAIRO
 		w = go_format_sel_new_full (TRUE);
-#else
-		w = go_format_sel_new_full (FALSE);
-#endif
+		state->format_selector = w;
+
 		if (axis->assigned_format != NULL && !go_format_is_general (axis->assigned_format))
 			go_format_sel_set_style_format (GO_FORMAT_SEL (w),
 				axis->assigned_format);
@@ -1584,8 +1710,8 @@ gog_axis_populate_editor (GogObject *gobj,
 	}
 
 	w = glade_xml_get_widget (gui, "axis_pref_box");
-	g_object_set_data_full (G_OBJECT (w), "gui", gui,
-				(GDestroyNotify)g_object_unref);
+	g_object_set_data_full (G_OBJECT (w), "state", state,
+				(GDestroyNotify)gog_axis_pref_state_free);
 
 	gog_editor_set_store_page (editor, &axis_pref_page);
 }
@@ -1646,6 +1772,17 @@ gog_axis_class_init (GObjectClass *gobject_klass)
 		g_param_spec_string ("assigned-format-string-XL", NULL,
 			"The user assigned format to use for non-discrete axis labels (XL format)",
 			"General", G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+	g_object_class_install_property (gobject_klass, AXIS_PROP_CIRCULAR_ROTATION,
+		g_param_spec_double ("circular-rotation", "Rotation of circular axis", 
+				     "Rotation of circular axis",
+				     GOG_AXIS_CIRCULAR_ROTATION_MIN, 
+				     GOG_AXIS_CIRCULAR_ROTATION_MAX,
+				     0.0, G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
+	g_object_class_install_property (gobject_klass, AXIS_PROP_POLAR_UNIT,
+		g_param_spec_string ("polar-unit", "Polar axis set unit", 
+				     "Polar axis set unit", 
+				     polar_units[GOG_AXIS_POLAR_UNIT_DEGREES].name,
+				     G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
 
 	gog_object_register_roles (gog_klass, roles, G_N_ELEMENTS (roles));
 
@@ -1676,6 +1813,9 @@ gog_axis_init (GogAxis *axis)
 
 	gog_axis_map_set (axis, NULL);
 
+	axis->polar_unit = GOG_AXIS_POLAR_UNIT_DEGREES;
+	axis->circular_rotation = 0;
+
 	axis->ticks = NULL;
 	axis->tick_nbr = 0;
 }
@@ -1982,6 +2122,73 @@ gog_axis_get_grid_line (GogAxis *axis, gboolean major)
 	return NULL;
 }
 
+/**
+ * gog_axis_set_polar_unit:
+ * @axis: a #GogAxis
+ * @unit: #GogAxisPolarUnit
+ *
+ * Sets unit of a circular axis. See #GogAxisPolarUnit for valid
+ * values. 
+ **/
+
+void
+gog_axis_set_polar_unit (GogAxis *axis, GogAxisPolarUnit unit)
+{
+	g_return_if_fail (IS_GOG_AXIS (axis));
+
+	axis->polar_unit = CLAMP (unit, 0, GOG_AXIS_POLAR_UNIT_MAX - 1);
+}
+
+/**
+ * gog_axis_get_polar_unit:
+ * @axis: a #GogAxis
+ *
+ * returns: unit of @axis if it's a circular axis of a polar
+ * axis set, -1 otherwise.
+ **/
+
+GogAxisPolarUnit
+gog_axis_get_polar_unit (GogAxis *axis)
+{
+	g_return_val_if_fail (IS_GOG_AXIS (axis), 0);
+
+	return axis->polar_unit;
+}
+
+/**
+ * gog_axis_get_circular_perimeter:
+ * @axis: a #GogAxis
+ *
+ * returns: perimeter of a circular #GogAxis of a polar axis set.
+ * 
+ * 	radians: 2*pi
+ * 	degrees: 360.0
+ * 	grads  : 400.0
+ **/
+
+double
+gog_axis_get_polar_perimeter (GogAxis *axis)
+{
+	g_return_val_if_fail (IS_GOG_AXIS (axis), 0.0);
+
+	return polar_units[axis->polar_unit].perimeter;
+}
+
+/**
+ * gog_axis_get_circular_rotation:
+ * @axis: a #GogAxis
+ *
+ * returns: rotation of a circular #GogAxis.
+ **/
+
+double
+gog_axis_get_circular_rotation (GogAxis *axis)
+{
+	g_return_val_if_fail (IS_GOG_AXIS (axis), 0.0);
+
+	return axis->circular_rotation;
+}
+
 /****************************************************************************/
 
 typedef GogAxisBaseView		GogAxisView;
